Empty State handler.
In some cases it is possible for an Event to be received before the first State is set.
This is the callback for these cases.
To avoid this, when needed, consider using waitForState before adding any Events.
See BlocSubject.defaultEmptyHandler for modifying the default implementation.